@@ -37,7 +37,13 @@ class PilPlus():
         elif type(img) == PilPlus:
             self.img = img.get_image()
         else:
-            self.img = Image.open(img)
+            try:
+                # open image from path
+                self.img = Image.open(img)
+            except FileNotFoundError as e:
+                # maybe it's a base64 string instead of a path
+                buff = BytesIO(base64.b64decode(img))
+                self.img = Image.open(buff)
 
     def get_width(self) -> int:
         """
@@ -819,4 +825,6 @@ class PilPlus():
 
         buffered = BytesIO()
         self.img.save(buffered, format="JPEG")
-        return base64.b64encode(buffered.getvalue())
\ No newline at end of file
+        return base64.b64encode(buffered.getvalue())
+
+    
\ No newline at end of file
